@@ -21,6 +21,7 @@ name_in_module = True
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_lambda_namespace():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -43,6 +44,7 @@ b = lambda arg, *args, **kwargs: arg + 1
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_function_namespace():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -76,6 +78,7 @@ def func(arg, *args, **kwargs):
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_async_function_namespace():
     if sys.version_info < (3, 5):
         pytest.skip('No async functions in python < 3.5')
@@ -109,6 +112,7 @@ async def func(arg, *args, **kwargs):
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 # region generator namespace
 
 def test_generator_namespace():
@@ -129,6 +133,7 @@ a = (x for x in range(10))
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_generator_namespace():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -150,6 +155,7 @@ a = (x for x in f for x in x)
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_generator_namespace_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -174,6 +180,7 @@ a = (c for line in file for c in line)
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_generator():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -199,6 +206,7 @@ a = (c for c in (line for line in file))
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_generator_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -220,6 +228,7 @@ a = (x for x in (x for x in x))
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 # endregion
 
 
@@ -243,6 +252,7 @@ a = {x for x in range(10)}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_setcomp_namespace():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -264,6 +274,7 @@ a = {x for x in f for x in x}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_setcomp_namespace_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -288,6 +299,7 @@ a = {c for line in file for c in line}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_setcomp():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -313,6 +325,7 @@ a = {c for c in {line for line in file}}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_setcomp_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -334,6 +347,7 @@ a = {x for x in {x for x in x}}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 # endregion
 
 # region listcomp
@@ -356,6 +370,7 @@ a = [x for x in range(10)]
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_listcomp_namespace():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -377,6 +392,7 @@ a = [x for x in f for x in x]
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_listcomp_namespace_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -401,6 +417,7 @@ a = [c for line in file for c in line]
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_listcomp():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -426,6 +443,7 @@ a =[c for c in [line for line in file]]
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_listcomp_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -447,6 +465,7 @@ a =[x for x in [x for x in x]]
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 # endregion
 
 # region dictcomp
@@ -469,6 +488,7 @@ a = {x: x for x in range(10)}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_dictcomp_namespace():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -490,6 +510,7 @@ a = {x: x for x, x in f for x, x in x}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_multi_dictcomp_namespace_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -514,6 +535,7 @@ a = {c: c for line, line in file for c, c in line}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_dictcomp():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -539,6 +561,7 @@ a = {c: c for c, c in {line: line for line in file}}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_nested_dictcomp_2():
     if sys.version_info < (3, 4):
         pytest.skip('Test requires python 3.4 or later')
@@ -560,6 +583,7 @@ a = {x:x  for x, x in {x: x for x in x}}
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 # endregion
 
 def test_class_namespace():
@@ -611,7 +635,7 @@ def func():
   class C:
     OhALongName = OhALongName + ' World'
     MyOtherName = OhALongName
-    
+
 
 func()
 '''
@@ -630,6 +654,7 @@ func()
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_name_allow_rename():
     source = '''
 MyNonLocal = 1
@@ -650,6 +675,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_name_disallow_rename():
     source = '''
 class LazyList:
@@ -667,6 +693,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_builtin_name_allow_rename():
     source = '''
 class LazyList:
@@ -685,6 +712,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_builtin_name_disallow_rename():
     source = '''
 class LazyList:
@@ -727,6 +755,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_name_disallow_rename():
     source = '''
 MyNonLocal = 1
@@ -748,7 +777,8 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
-def test_class_namespace_undefined_nonlocal_name_disallow_rename():
+
+def test_class_namespace_undefined_nonlocal_name_disallow_rename_2():
     source = '''
 class LazyList:
     MyAttribute = MyNonLocal
@@ -766,6 +796,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_import_as_disallow_rename():
     """import os as MyNonLocal"""
     source = '''
@@ -788,6 +819,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_import_as_disallow_rename():
     source = '''
 class LazyList:
@@ -807,6 +839,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_import_from_as_disallow_rename():
     source = '''
 MyNonLocal = 1
@@ -828,6 +861,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_import_from_as_disallow_rename():
     source = '''
 class LazyList:
@@ -847,6 +881,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_import_disallow_rename():
     source = '''
 MyNonLocal = 1
@@ -868,6 +903,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_import_disallow_rename():
     source = '''
 class LazyList:
@@ -887,6 +923,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_import_from_disallow_rename():
     source = '''
 MyNonLocal = 1
@@ -908,6 +945,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_import_from_disallow_rename():
     source = '''
 class LazyList:
@@ -927,6 +965,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_dotted_import_disallow_rename():
     source = '''
 MyNonLocal = 1
@@ -948,6 +987,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_dotted_import_disallow_rename():
     source = '''
 class LazyList:
@@ -967,6 +1007,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_func_disallow_rename():
     source = '''
 MyNonLocal = 1
@@ -989,6 +1030,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_func_disallow_rename():
     source = '''
 class LazyList:
@@ -1009,6 +1051,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_async_func_disallow_rename():
     if sys.version_info < (3, 5):
         pytest.skip('No async functions in python < 3.5')
@@ -1034,6 +1077,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_async_func_disallow_rename():
     if sys.version_info < (3, 5):
         pytest.skip('No async functions in python < 3.5')
@@ -1057,6 +1101,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_classdef_disallow_rename():
     source = '''
 MyNonLocal = 1
@@ -1079,6 +1124,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_classdef_disallow_rename():
     source = '''
 class LazyList:
@@ -1126,6 +1172,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_except_disallow_rename():
     source = '''
 class LazyList:
@@ -1133,7 +1180,7 @@ class LazyList:
     try:
         pass
     except Exception as MyNonLocal:
-        pass        
+        pass
 
 '''
 
@@ -1158,7 +1205,7 @@ def test_class_namespace_nonlocal_match_disallow_rename():
     source = '''
 MyNonLocal = 1
 Blah = "Hello"
-    
+
 class LazyList:
     MyAttribute = MyNonLocal
     match Blah:
@@ -1179,6 +1226,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_match_disallow_rename():
     if sys.version_info < (3, 10):
         pytest.skip('Match statement not in python < 3.10')
@@ -1189,7 +1237,7 @@ class LazyList:
     MyAttribute = MyNonLocal
     match Blah:
         case MyNonLocal:
-            pass  
+            pass
 '''
 
     expected_namespaces = '''
@@ -1205,6 +1253,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_match_star_disallow_rename():
     if sys.version_info < (3, 10):
         pytest.skip('Match statement not in python < 3.10')
@@ -1233,6 +1282,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_match_star_disallow_rename():
     if sys.version_info < (3, 10):
         pytest.skip('Match statement not in python < 3.10')
@@ -1243,7 +1293,7 @@ class LazyList:
     MyAttribute = MyNonLocal
     match Blah:
         case [*MyNonLocal]:
-            pass  
+            pass
 '''
 
     expected_namespaces = '''
@@ -1259,6 +1309,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_match_mapping_disallow_rename():
     if sys.version_info < (3, 10):
         pytest.skip('Match statement not in python < 3.10')
@@ -1287,6 +1338,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_match_mapping_disallow_rename():
     if sys.version_info < (3, 10):
         pytest.skip('Match statement not in python < 3.10')
@@ -1297,7 +1349,7 @@ class LazyList:
     MyAttribute = MyNonLocal
     match Blah:
         case {**MyNonLocal}:
-            pass  
+            pass
 '''
 
     expected_namespaces = '''
@@ -1313,6 +1365,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_nonlocal_disallow_rename():
     if sys.version_info < (3, 0):
         pytest.skip('nonlocal in class is invalid in Python 2')
@@ -1334,6 +1387,7 @@ class LazyList:
 
     assert_namespace_tree(source, expected_namespaces)
 
+
 def test_class_namespace_undefined_nonlocal_disallow_rename():
     if sys.version_info < (3, 0):
         pytest.skip('nonlocal in class is invalid in Python 2')
