@@ -1,16 +1,21 @@
 import ast
-from python_minifier import add_namespace, bind_names, resolve_names
-from python_minifier.transforms.remove_pass import RemovePass
+
+from python_minifier.ast_annotation import add_parent
 from python_minifier.ast_compare import compare_ast
+from python_minifier.rename import add_namespace, bind_names, resolve_names
+from python_minifier.transforms.remove_pass import RemovePass
+
 
 def remove_literals(source):
     module = ast.parse(source, 'remove_literals')
 
+    add_parent(module)
     add_namespace(module)
     bind_names(module)
     resolve_names(module)
     return RemovePass()(module)
 
+
 def test_remove_pass_empty_module():
     source = 'pass'
     expected = ''
@@ -19,6 +24,7 @@ def test_remove_pass_empty_module():
     actual_ast = remove_literals(source)
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_pass_module():
     source = '''import collections
 pass
@@ -31,6 +37,7 @@ a=1'''
     actual_ast = remove_literals(source)
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_if_empty():
     source = '''if True:
     pass'''
@@ -41,6 +48,7 @@ def test_remove_if_empty():
     actual_ast = remove_literals(source)
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_if_line():
     source = '''if True: pass'''
     expected = '''if True: 0'''
@@ -49,20 +57,22 @@ def test_remove_if_line():
     actual_ast = remove_literals(source)
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_suite():
-    source = '''if True: 
+    source = '''if True:
+    pass
+    a=1
     pass
-    a=1 
-    pass 
     return None'''
     expected = '''if True:
-    a=1 
+    a=1
     return None'''
 
     expected_ast = ast.parse(expected)
     actual_ast = remove_literals(source)
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_from_class():
     source = '''class A:
     pass
@@ -83,6 +93,7 @@ def test_remove_from_class():
     actual_ast = remove_literals(source)
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_from_class_empty():
     source = '''class A:
     pass
@@ -93,6 +104,7 @@ def test_remove_from_class_empty():
     actual_ast = remove_literals(source)
     compare_ast(expected_ast, actual_ast)
 
+
 def test_remove_from_class_func_empty():
     source = '''class A:
     def b():
