@@ -9,25 +9,29 @@ import sys
 
 import pytest
 
-from python_minifier import add_namespace, bind_names, resolve_names, allow_rename_locals, allow_rename_globals, \
-    compare_ast, rename, CompareError, unparse
+from python_minifier import unparse
+from python_minifier.ast_annotation import add_parent
+from python_minifier.ast_compare import CompareError, compare_ast
+from python_minifier.rename import add_namespace, allow_rename_globals, allow_rename_locals, bind_names, rename, resolve_names
 
 
 def rename_locals(source):
 
     # This will raise if the source file can't be parsed
     module = ast.parse(source, 'test_rename_locals')
+    add_parent(module)
     add_namespace(module)
     bind_names(module)
     resolve_names(module)
 
-    allow_rename_locals(module, True)
-    allow_rename_globals(module, False)
+    allow_rename_locals(module, rename_locals=True)
+    allow_rename_globals(module, rename_globals=False)
 
     rename(module)
 
     return module
 
+
 def assert_code(expected_ast, actual_ast):
     try:
         compare_ast(expected_ast, actual_ast)
@@ -51,6 +55,7 @@ def a():
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_rename_multiple_definitions():
     source = '''
 def inner(my_name):
@@ -70,6 +75,7 @@ def inner(my_name):
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_rename_self_cls_in_place():
     source = '''
 class TestClass():
@@ -80,27 +86,27 @@ class TestClass():
 
     @staticmethod
     def mystatic(cls): return cls
-    @staticmethod    
+    @staticmethod
     def mystatic(asdfghjkl): return asdfghjkl
-    @staticmethod    
+    @staticmethod
     def mystatic(): return 'No cls'
-    
+
     @classmethod
     def mystatic(cls): return cls
-    @classmethod    
+    @classmethod
     def mystatic(asdfghjkl): return asdfghjkl
-    @classmethod    
+    @classmethod
     def mystatic(): return 'No cls'
-    
+
     @unknown_decorator
     def unknown(self): return self
-    @unknown_decorator    
+    @unknown_decorator
     def unknown(qwertyuiop): return qwertyuiop
-    @unknown_decorator        
+    @unknown_decorator
     def unknown(self, arg): return self, arg
-    @unknown_decorator    
-    def unknown(): return 'No arg'        
-    
+    @unknown_decorator
+    def unknown(): return 'No arg'
+
 '''
     expected = '''
 class TestClass():
@@ -111,26 +117,26 @@ class TestClass():
 
     @staticmethod
     def mystatic(cls): return cls
-    @staticmethod    
+    @staticmethod
     def mystatic(asdfghjkl): return asdfghjkl
-    @staticmethod    
+    @staticmethod
     def mystatic(): return 'No cls'
-    
+
     @classmethod
     def mystatic(A): return A
-    @classmethod    
+    @classmethod
     def mystatic(A): return A
-    @classmethod    
+    @classmethod
     def mystatic(): return 'No cls'
-    
+
     @unknown_decorator
     def unknown(self): return self
-    @unknown_decorator    
+    @unknown_decorator
     def unknown(qwertyuiop): return qwertyuiop
-    @unknown_decorator        
+    @unknown_decorator
     def unknown(self, arg): return self, arg
-    @unknown_decorator    
-    def unknown(): return 'No arg'        
+    @unknown_decorator
+    def unknown(): return 'No arg'
 '''
 
     expected_ast = ast.parse(expected)
@@ -142,22 +148,22 @@ def test_rename_arg_kwargs_in_place():
     source = '''
 def test(arg, arg2, *args, **kwargs): return args, kwargs
 def samename(arg, arg2, *asd, **asd): return asd
-    
+
 class TestClass():
     def mymethod(self, arg, *args, **kwargs): return args, kwargs
-    
+
     @classmethod
     def mymethod(cls, arg, *args, **kwargs): return args, kwargs
 '''
     expected = '''
 def test(arg, arg2, *A, **B): return A, B
 def samename(arg, arg2, *A, **A): return A
-    
+
 class TestClass():
     def mymethod(C, arg, *A, **B): return A, B
-    
+
     @classmethod
-    def mymethod(C, arg, *A, **B): return A, B   
+    def mymethod(C, arg, *A, **B): return A, B
 '''
 
     expected_ast = ast.parse(expected)
@@ -258,7 +264,7 @@ def test_rename_long_arg():
     source = '''
 def f(this_is_my_long_argument_name):
     print(this_is_my_long_argument_name)
-    print(this_is_my_long_argument_name)    
+    print(this_is_my_long_argument_name)
 '''
     expected = '''
 def f(this_is_my_long_argument_name):
@@ -271,30 +277,32 @@ def f(this_is_my_long_argument_name):
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_no_rename_single_char_arg():
     source = '''
 def f(a):
     print(a)
     print(a)
     print(a)
-    print(a) 
-    print(a)  
-    print(a) 
-    print(a) 
-    print(a) 
-    print(a) 
-    print(a) 
-    print(a) 
-    print(a) 
-    print(a) 
-    print(a) 
-    print(a)                     
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
+    print(a)
 '''
 
     expected_ast = ast.parse(source)
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_rename_arg():
     source = '''
 def f(aa):
@@ -302,7 +310,7 @@ def f(aa):
     print(aa)
     print(aa)
     print(aa)
-    print(aa)                           
+    print(aa)
 '''
     expected = '''
 def f(aa):
@@ -311,73 +319,78 @@ def f(aa):
     print(A)
     print(A)
     print(A)
-    print(A)                   
+    print(A)
 '''
 
     expected_ast = ast.parse(expected)
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_no_rename_lambda_arg():
     source = '''
-lambda my_argument: f(my_argument + my_argument + my_argument)                       
+lambda my_argument: f(my_argument + my_argument + my_argument)
 '''
 
     expected_ast = ast.parse(source)
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_rename_lambda_stararg():
     source = '''
-lambda *args, **kwargs: f(args, kwargs)                       
+lambda *args, **kwargs: f(args, kwargs)
 '''
 
     expected = '''
-lambda *A, **B: f(A, B)                       
+lambda *A, **B: f(A, B)
 '''
 
     expected_ast = ast.parse(expected)
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_python3_listcomp_scope():
     if sys.version_info < (3, 0):
         pytest.skip('No list comprehension scope in python < 3.0')
 
     source = '''
-[a for a in mylist]                     
+[a for a in mylist]
 '''
 
     expected = '''
-[A for A in mylist]                     
+[A for A in mylist]
 '''
 
     expected_ast = ast.parse(expected)
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_python2_listcomp_scope():
     if sys.version_info >= (3, 0):
         pytest.skip('list comprehension scope in python >= 3.0')
 
     source = '''
-[a for a in mylist]               
+[a for a in mylist]
 def t():
     a = True
-    [a for a in mylist] 
+    [a for a in mylist]
 '''
 
     expected = '''
-[a for a in mylist]               
+[a for a in mylist]
 def t():
     A = True
-    [A for A in mylist]                    
+    [A for A in mylist]
 '''
 
     expected_ast = ast.parse(expected)
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_arg_rename():
 
     source = '''
@@ -390,10 +403,11 @@ def f(*A,**B):pass
     actual_ast = rename_locals(source)
     assert_code(expected_ast, actual_ast)
 
+
 def test_multiple_args():
     source = '''
 def f(hello, hello):
-    print(hello + hello)      
+    print(hello + hello)
     '''
     expected = '''
 def f(hello, hello):
